@@ -191,7 +191,7 @@ def _parse_aggregate_query(model_class, info, aggregate_properties):
         return grouped_fields, aggregated_fields_by_fn
 
     parent_type = info.parent_type.fields.get(info.field_name).type
-    selections = info.field_asts[0].selection_set.selections
+    selections = info.field_nodes[0].selection_set.selections
     return _inner_parse_aggregate_query(
         model_class,
         getattr(parent_type, "of_type", parent_type),
