@@ -23,7 +23,7 @@ class ListUpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
             "{}ListUpdateInput".format(model_class.__name__),
             (InputObjectType,),
             {
-                "update_strategy": UpdateStrategy(required=True, default="merge"),
+                "update_strategy": UpdateStrategy(required=True, default_value="merge"),
                 "items": List(nested_item_update_input_type, required=True),
             },
         )
